pub struct LeaseGuard { /* private fields */ }Expand description
Active short-term reservation against the budget.
While alive, the effective per-cache target is reduced by
bytes(). The reduction is released when the guard is dropped.
Issued by MemoryBudget::lease.
The guard holds a Weak reference to the budget so that a guard
outliving its budget does not leak the budget’s allocation.
Implementations